@@ -103,7 +103,7 @@ class Excel:
         # TODO
 
         # write out the new sheet
-        df.to_excel(writer, sheet_name, startrow=startrow, header=header, if_sheet_exists='overlay', **to_excel_kwargs)
+        df.to_excel(writer, sheet_name, startrow=startrow, header=header, **to_excel_kwargs)
 
         # save the workbook
         writer.save()
